package ur_rna.Utilities;

/**
 * Created by Richard on 3/19/2015.
 */
public class Convert {
    private Convert() {}
    public static boolean ToBool(Object obj) {
        if (obj == null) return false;
        if (obj instanceof Boolean)
            return (Boolean) obj;
        if (obj instanceof Number)
            return ((Number)obj).doubleValue() == 0d;
        if (obj instanceof String)
            return ToBool((String)obj);
        if (obj instanceof Void)
            return false;
        if (obj instanceof java.util.Optional<?>)
            return ((java.util.Optional<?>)obj).isPresent();
        return true;
    }
    public static boolean ToBool(String s) {
        if (s == null || s.length() == 0) return false;
        s = s.toUpperCase();
        return !(
                s.equals("F")
                        || s.equals("FALSE")
                        || s.equals("NO")
                        || s.equals("0")
        );
    }
    public static int ToInt(String s, int def) {
        if (s == null) return def;
        try {
            return Integer.parseInt(s);
        }catch (NumberFormatException e) {
            return def;
        }
    }
    public static double ToDouble(String s, double def) {
        if (s == null) return def;
        try {
            return Double.parseDouble(s);
        }catch (NumberFormatException e) {
            return def;
        }
    }
    /**
     * Converts a standard POSIX Shell globbing pattern into a regular expression
     * pattern. The result can be used with the standard {@link java.util.regex} API to
     * recognize strings which match the glob pattern.
     * <p>
     * See also, the POSIX Shell language:
     * http://pubs.opengroup.org/onlinepubs/009695399/utilities/xcu_chap02.html#tag_02_13_01
     * By: Neil Traft - http://stackoverflow.com/questions/1247772/is-there-an-equivalent-of-java-util-regex-for-glob-type-patterns
     * </p>
     * @param pattern A glob pattern.
     * @return A regex pattern to recognize the given glob pattern.
     *
     */
    public static String globToRegex(String pattern) {
        StringBuilder sb = new StringBuilder(pattern.length());
        int inGroup = 0;
        int inClass = 0;
        int firstIndexInClass = -1;
        char[] arr = pattern.toCharArray();
        for (int i = 0; i < arr.length; i++) {
            char ch = arr[i];
            switch (ch) {
                case '\\':
                    if (++i >= arr.length) {
                        sb.append('\\');
                    } else {
                        char next = arr[i];
                        switch (next) {
                            case ',':
                                // escape not needed
                                break;
                            case 'Q':
                            case 'E':
                                // extra escape needed
                                sb.append('\\');
                            default:
                                sb.append('\\');
                        }
                        sb.append(next);
                    }
                    break;
                case '*':
                    if (inClass == 0)
                        sb.append(".*");
                    else
                        sb.append('*');
                    break;
                case '?':
                    if (inClass == 0)
                        sb.append('.');
                    else
                        sb.append('?');
                    break;
                case '[':
                    inClass++;
                    firstIndexInClass = i+1;
                    sb.append('[');
                    break;
                case ']':
                    inClass--;
                    sb.append(']');
                    break;
                case '.':
                case '(':
                case ')':
                case '+':
                case '|':
                case '^':
                case '$':
                case '@':
                case '%':
                    if (inClass == 0 || (firstIndexInClass == i && ch == '^'))
                        sb.append('\\');
                    sb.append(ch);
                    break;
                case '!':
                    if (firstIndexInClass == i)
                        sb.append('^');
                    else
                        sb.append('!');
                    break;
                case '{':
                    inGroup++;
                    sb.append('(');
                    break;
                case '}':
                    inGroup--;
                    sb.append(')');
                    break;
                case ',':
                    if (inGroup > 0)
                        sb.append('|');
                    else
                        sb.append(',');
                    break;
                default:
                    sb.append(ch);
            }
        }
        return sb.toString();
    }
}
